==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":                 $messaggio = "Buchung erfassen"; break;
case "Cliente titolare: cognome":                        $messaggio = "Nachname "; break;
case "cognome":                                          $messaggio = "Nachname"; break;
case "nome":                                             $messaggio = "Vorname"; break;
case "Dal":                                              $messaggio = "Ab"; break;
case "dal":                                              $messaggio = "von"; break;
case "al":                                               $messaggio = "bis"; break;
case "Tipo di tariffa":                                  $messaggio = "Preis Kategorie"; break;
case "tariffa":                                          $messaggio = "Preis"; break;
case "sconto":                                           $messaggio = "Rabatt"; break;
case "caparra":                                          $messaggio = "Anzahlung"; break;
case "se diversa dalla normale":                         $messaggio = "wenn abweichend vom Standard"; break;
case "nº di persone":                                   $messaggio = "Anzahl Personen"; break;
case "Nº di piano":                                     $messaggio = "Flur Nummer"; break;
case "e/o di casa":                                      $messaggio = "und/oder Hausnummer"; break;
case "e/o di persone":                                   $messaggio = "und/oder Personenanzahl"; break;
case "costo aggiuntivo unico":                           $messaggio = "Einmaliger Zuschlag"; break;
case "da moltiplicare per":                              $messaggio = "zu multiplizieren mit"; break;
case "costo aggiuntivo settimanale":                     $messaggio = "w&ouml;chentlichen Zuschl&auml;ge f&uuml;r"; break;
case "costo aggiuntivo giornaliero":                     $messaggio = "t&auml;glichen Zuschl&auml;ge f&uuml;r"; break;
case "nº di settimane da applicare":                    $messaggio = "Anzahl der Wochen"; break;
case "nº di giorni da applicare":                       $messaggio = "Anzahl der Tage"; break;
case "Commento":                                         $messaggio = "Bemerkungen"; break;
case "Inserisci la prenotazione":                        $messaggio = "Reservierung speichern"; break;
case "Torna al menù principale":                        $messaggio = "Hauptmen&uuml;"; break;
case " o spezzarla":                                     $messaggio = " oder teile es"; break;
case "Spezza la prenotazione in":                        $messaggio = "Teile Reservierung in"; break;
case "parti":                                            $messaggio = "Teile"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":        $messaggio = "Es war nicht m&ouml;glich die Reservierung zu teilen, weil die Zahl der Personen"; break;
case "Non è possibile inserire la prenotazione senza":  $messaggio = "Es ist nicht m&ouml;glich die Reservierung einzutragen ohne"; break;
case "dividerla":                                        $messaggio = "teile sie"; break;
case "in":                                               $messaggio = "im"; break;
case "Spezza la prenotazione in":                        $messaggio = "Teile Reservierung in"; break;
case "Non si è potuto inserire la prenotazione a nome di":      $messaggio = "Es war nicht m&ouml;glich die Reservierung einzutragen f&uuml;r"; break;
case "perchè il database è stato modificato nel frattempo":    $messaggio = "weil die Datenbank inzwischen ge&auml;ndert wurde"; break;
case "Prenotazione":                                     $messaggio = "Reservierung No."; break;
case "settiman":                                         $messaggio = "Woche"; break;
case "giorn":                                            $messaggio = "Tag"; break;
case "e":                                                $messaggio = "eee"; break;
case "a":                                                $messaggio = "xxx"; break;
case "o":                                                $messaggio = ""; break;   // Endung Einzahl bei Tag case "i":                                                $messaggio = "e"; break;
case "i":                                                $messaggio = "e"; break;
case "a nome di":                                        $messaggio = "f&uuml;r Herrn/Frau"; break;
case "per":                                              $messaggio = "f&uuml;r"; break;
case "persone":                                          $messaggio = "Personen"; break;
case "Costo unico":                                      $messaggio = "Einmalkosten"; break;
case "moltiplicato per":                                 $messaggio = "multipliziert mit"; break;
case "Costo settimanale":                                $messaggio = "w&ouml;chentliche Kosten"; break;
case "Costo giornaliero":                                $messaggio = "t&auml;gliche Kosten"; break;
case "settimane":                                        $messaggio = "Wochen"; break;
case "giorni":                                           $messaggio = "Tage"; break;
case "TOTALE":                                           $messaggio = "<b>Summe<b>"; break;
case "Caparra":                                          $messaggio = "Anzahlung"; break;
case "resto da pagare":                                  $messaggio = "Restzahlung"; break;
case "Commento":                                         $messaggio = "Bemerkungen"; break;
case "inserita":                                         $messaggio = "eingegeben"; break;
case "Modifica la prenotazione":                         $messaggio = "Reservierung &auml;ndern"; break;
case "Torna indietro":                                   $messaggio = "Zur&uuml;ck"; break;
case "Sconto":                                           $messaggio = "Rabatt"; break;
case "É necessario inserire il cognome del cliente":    $messaggio = "Der Nachname des Kunden ist erforderlich"; break;
case "confermata":                                       $messaggio = "best&auml;tigt"; break;
case "Confermata":                                       $messaggio = "Best&auml;tigung"; break;
case "Nº di prenotazioni di questa tipologia":          $messaggio = "Anzahl der anzulegenden Reservierungen"; break;
case "Aggiungi altre tipologie":                         $messaggio = "weitere Buchungsmaske hinzuf&uuml;gen"; break;
case "Tipologia":                                        $messaggio = "<b>Buchung No.: </b>"; break;
case "Nessuna nuova prenotazione è stata inserita":     $messaggio = "Es wurde keine Reservierung eingetragen"; break;
case "Transazione scaduta":                              $messaggio = "Transaktion abgelaufen"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":        $messaggio = "Zuschlag konnte zu dieser Reservierung nicht hinzugef&uuml;gt werden"; break;
case "Orario stimato di entrata":                        $messaggio = "vorraussichtlicher CheckIn"; break;
case "giorno":                                           $messaggio = "Tag (des gebuchten Zeitraums)"; break;
case "Metodo pagamento caparra":                         $messaggio = "Zahlungsweise der Anzahlung"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":        $messaggio = "Die in der Mitteilung angefragten Reservierungen wurden bereits eingef&uuml;gt"; break;
case "Attenzione":                                       $messaggio = "Achtung"; break;
case "il prezzo totale delle prenotazioni inserite":     $messaggio = "der Gesamtpreis der eingef&uuml;gten Reservierung"; break;
case "il prezzo totale delle caparre inserite":          $messaggio = "die Summe der eingef&uuml;gten Anzahlungen"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":        $messaggio = "unterscheidet sich von dem in der Reservierunganfrage genannten Betrag"; break;
case "Origine":                                          $messaggio = "Original"; break;
case "<b>Attenzione</b>: il prezzo totale":              $messaggio = "<b>Hinweis</b>: Gesamtsumme"; break;
case "non coincide con il prezzo remoto":                $messaggio = "Differenz zum Preis"; break;
case "Modifica come gruppo le prenotazioni inserite":    $messaggio = "&Auml;ndern der Reservierungen aus der Gruppe"; break;
case "prezzo totale":                                    $messaggio = "Gesamtpreis"; break;
case "prezzo totale giornaliero":                        $messaggio = "Summe Tagespreis"; break;
case "prezzo totale settimanale":                        $messaggio = "Summe Wochenpreis"; break;
case "prezzo tarffa":                                    $messaggio = "Tagessatz"; break;
case "prezzo tariffa giornaliero":                       $messaggio = "Tagessatz Preis"; break;
case "prezzo tariffa settimanale":                       $messaggio = "Wochensatz Preis"; break;
case "% del totale":                                     $messaggio = "% auf Summe"; break;
case "% della tariffa":                                  $messaggio = "% &uuml;ber Nachlass"; break;
case "Commissioni":                                      $messaggio = "Nachl&auml;sse"; break;
case "resto commissioni":                                $messaggio = "offene Provisionen"; break;
case "% del prezzo totale":  			$messaggio = "% of total price"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_2.1.2-1.tar.gz: de/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":                 $messaggio = "Buchung erfassen"; break;
case "Cliente titolare: cognome":                        $messaggio = "Nachname "; break;
case "cognome":                                          $messaggio = "Nachname"; break;
case "nome":                                             $messaggio = "Vorname"; break;
case "Dal":                                              $messaggio = "Vom"; break;
case "dal":                                              $messaggio = "von"; break;
case "al":                                               $messaggio = "bis"; break;
case "Tipo di tariffa":                                  $messaggio = "Preis Kategorie"; break;
case "tariffa":                                          $messaggio = "Preis"; break;
case "sconto":                                           $messaggio = "Rabatt"; break;
case "caparra":                                          $messaggio = "Anzahlung"; break;
case "se diversa dalla normale":                         $messaggio = "wenn abweichend vom Standard"; break;
case "nº di persone":                                    $messaggio = "Anzahl Personen"; break;
case "Nº di piano":                                      $messaggio = "Flur Nummer"; break;
case "e/o di casa":                                      $messaggio = "und/oder Hausnummer"; break;
case "e/o di persone":                                   $messaggio = "und/oder Personenanzahl"; break;
case "costo aggiuntivo unico":                           $messaggio = "Einmaliger Zuschlag"; break;
case "da moltiplicare per":                              $messaggio = "zu multiplizieren mit"; break;
case "costo aggiuntivo settimanale":                     $messaggio = "w&ouml;chentlichen Zuschl&auml;ge f&uuml;r"; break;
case "costo aggiuntivo giornaliero":                     $messaggio = "t&auml;glichen Zuschl&auml;ge f&uuml;r"; break;
case "nº di settimane da applicare":                     $messaggio = "Anzahl der Wochen"; break;
case "nº di giorni da applicare":                        $messaggio = "Anzahl der Tage"; break;
case "Commento":                                         $messaggio = "Bemerkungen"; break;
case "Inserisci la prenotazione":                        $messaggio = "Reservierung speichern"; break;
case "Torna al menù principale":                         $messaggio = "Hauptmen&uuml;"; break;
case " o spezzarla":                                     $messaggio = " oder teile es"; break;
case "Spezza la prenotazione in":                        $messaggio = "Teile Reservierung in"; break;
case "parti":                                            $messaggio = "Teile"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":        $messaggio = "Es war nicht m&ouml;glich die Reservierung zu teilen, weil die Zahl der Personen"; break;
case "Non è possibile inserire la prenotazione senza":   $messaggio = "Es ist nicht m&ouml;glich die Reservierung einzutragen ohne"; break;
case "dividerla":                                        $messaggio = "teile sie"; break;
case "in":                                               $messaggio = "im"; break;
case "Spezza la prenotazione in":                        $messaggio = "Teile Reservierung in"; break;
case "Non si è potuto inserire la prenotazione a nome di":      $messaggio = "Es war nicht m&ouml;glich die Reservierung einzutragen f&uuml;r"; break;
case "perchè il database è stato modificato nel frattempo":    $messaggio = "weil die Datenbank inzwischen ge&auml;ndert wurde"; break;
case "Prenotazione":                                     $messaggio = "Reservierung Nr."; break;
case "settiman":                                         $messaggio = "Woche"; break;
case "giorn":                                            $messaggio = "Tag"; break;
case "e":                                                $messaggio = "eee"; break;
case "a":                                                $messaggio = "xxx"; break;
case "o":                                                $messaggio = ""; break;   // Endung Einzahl bei Tag case "i":                                                $messaggio = "e"; break;
case "i":                                                $messaggio = "e"; break;
case "a nome di":                                        $messaggio = "f&uuml;r Herrn/Frau"; break;
case "per":                                              $messaggio = "f&uuml;r"; break;
case "persone":                                          $messaggio = "Personen"; break;
case "Costo unico":                                      $messaggio = "Einmalkosten"; break;
case "moltiplicato per":                                 $messaggio = "multipliziert mit"; break;
case "Costo settimanale":                                $messaggio = "w&ouml;chentliche Kosten"; break;
case "Costo giornaliero":                                $messaggio = "t&auml;gliche Kosten"; break;
case "settimane":                                        $messaggio = "Wochen"; break;
case "giorni":                                           $messaggio = "Tage"; break;
case "TOTALE":                                           $messaggio = "<b>Summe<b>"; break;
case "Caparra":                                          $messaggio = "Anzahlung"; break;
case "resto da pagare":                                  $messaggio = "Restzahlung"; break;
case "Commento":                                         $messaggio = "Bemerkungen"; break;
case "inserita":                                         $messaggio = "eingegeben"; break;
case "Modifica la prenotazione":                         $messaggio = "Reservierung &auml;ndern"; break;
case "Torna indietro":                                   $messaggio = "Zur&uuml;ck"; break;
case "Sconto":                                           $messaggio = "Rabatt"; break;
case "É necessario inserire il cognome del cliente":     $messaggio = "Der Nachname des Kunden ist erforderlich"; break;
case "confermata":                                       $messaggio = "best&auml;tigt"; break;
case "Confermata":                                       $messaggio = "Best&auml;tigung"; break;
case "Nº di prenotazioni di questa tipologia":           $messaggio = "Anzahl der anzulegenden Reservierungen"; break;
case "Aggiungi altre tipologie":                         $messaggio = "weitere Buchungsmaske hinzuf&uuml;gen"; break;
case "Tipologia":                                        $messaggio = "<b>Buchung Nr.: </b>"; break;
case "Nessuna nuova prenotazione è stata inserita":      $messaggio = "Es wurde keine Reservierung eingetragen"; break;
case "Transazione scaduta":                              $messaggio = "Transaktion abgelaufen"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":        $messaggio = "Zuschlag konnte zu dieser Reservierung nicht hinzugef&uuml;gt werden"; break;
case "Orario stimato di entrata":                        $messaggio = "vorraussichtlicher CheckIn"; break;
case "giorno":                                           $messaggio = "Tag (des gebuchten Zeitraums)"; break;
case "Metodo pagamento caparra":                         $messaggio = "Zahlungsweise der Anzahlung"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":        $messaggio = "Die in der Mitteilung angefragten Reservierungen wurden bereits eingef&uuml;gt"; break;
case "Attenzione":                                       $messaggio = "Achtung"; break;
case "il prezzo totale delle prenotazioni inserite":     $messaggio = "der Gesamtpreis der eingef&uuml;gten Reservierung"; break;
case "il prezzo totale delle caparre inserite":          $messaggio = "die Summe der eingef&uuml;gten Anzahlungen"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":        $messaggio = "unterscheidet sich von dem in der Reservierunganfrage genannten Betrag"; break;
case "Origine":                                          $messaggio = "Original"; break;
case "<b>Attenzione</b>: il prezzo totale":              $messaggio = "<b>Hinweis:</b> Gesamtsumme"; break;
case "non coincide con il prezzo remoto":                $messaggio = "Differenz zum Preis"; break;
case "Modifica come gruppo le prenotazioni inserite":    $messaggio = "&Auml;ndern der Reservierungen aus der Gruppe"; break;
case "prezzo totale":                                    $messaggio = "Gesamtpreis"; break;
case "prezzo totale giornaliero":                        $messaggio = "Summe Tagespreis"; break;
case "prezzo totale settimanale":                        $messaggio = "Summe Wochenpreis"; break;
case "prezzo tarffa":                                    $messaggio = "Tagessatz"; break;
case "prezzo tariffa giornaliero":                       $messaggio = "Tagessatz Preis"; break;
case "prezzo tariffa settimanale":                       $messaggio = "Wochensatz Preis"; break;
case "% del totale":                                     $messaggio = "% auf Summe"; break;
case "% della tariffa":                                  $messaggio = "% &uuml;ber Nachlass"; break;
case "Commissioni":                                      $messaggio = "Nachl&auml;sse"; break;
case "resto commissioni":                                $messaggio = "offene Provisionen"; break;
case "% del prezzo totale":  			         $messaggio = "% vom Gesamtpreis"; break;
case "modificata":  				$messaggio = "modified"; break;
case "Errore":  				$messaggio = "Error"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per l'entrata":  				$messaggio = "for checkin"; break;
case "per l'uscita":  				$messaggio = "for checkout"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
